import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import Box from './Box'
import ExclamationCircle from './ExclamationCircle'
import theme from './theme'

const styles = ({
  theme
}) => css`
  color: ${props => props.theme.context.white[0].textColor};
  box-shadow: inset 0 0 0 1px ${props => props.theme.context.white[0].borderColor[0]};

  &:focus,
  &:active {
    box-shadow: inset 0 0 0 1px ${props => props.theme.colors.primary[0]};
  }
`

const Input = styled(({ warning, ...props }) =>
  <Box position='relative'>
    {warning ? <ExclamationCircle position='absolute' top='50%' marginLeft='-5px' marginTop='-6px' /> : null}
    <Box {...props} />
  </Box>
)`${styles}`

Input.propTypes = {
  ...Box.propTypes,
  warning: PropTypes.bool
}

Input.defaultProps = {
  theme,
  is: 'input',
  rounded: true,
  width: '100%',
  paddingX: 4,
  paddingY: 2,
  textStyle: 'body1'
}

Input.displayName = 'Input'

export default Input
